﻿'Prologue
'Takes census data and converts it to an easier format

Public Class frmCityNamesConvert
    'Create arrays for storing data
    Dim mstrState() As String
    Dim mstrCity() As String
    Dim mintPop() As Integer
    Dim mintHousingUnits() As Integer
    Dim msngLandArea() As Single
    Dim msngWaterArea() As Single
    Dim mstrLatitude() As String
    Dim mstrLongitude() As String

    Private Sub btnExit_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnExit.Click
        End

    End Sub

    Private Sub btnConvert_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnConvert.Click
        Dim srdData As System.IO.StreamReader
        Dim strRecord As String
        Dim i As Integer
        Dim sngLatitude As Single
        Dim sngLongitude As Single

        srdData = New System.IO.StreamReader("CityNames.dat")

        'Reads file and populates array
        Do Until srdData.Peek = -1

            ReDim Preserve mstrState(i)
            ReDim Preserve mstrCity(i)
            ReDim Preserve mintPop(i)
            ReDim Preserve mintHousingUnits(i)
            ReDim Preserve msngLandArea(i)
            ReDim Preserve msngWaterArea(i)
            ReDim Preserve mstrLatitude(i)
            ReDim Preserve mstrLongitude(i)

            'Data is in fixed-width fields and cannot be split
            strRecord = srdData.ReadLine

            'Extracts data from fixed-width fields
            mstrState(i) = strRecord.Substring(0, 2)
            mstrCity(i) = strRecord.Substring(9, 63)
            mintPop(i) = Convert.ToInt32(strRecord.Substring(74, 9))
            mintHousingUnits(i) = Convert.ToInt32(strRecord.Substring(83, 9))
            msngLandArea(i) = Convert.ToSingle(strRecord.Substring(120, 12))
            sngLatitude = Convert.ToSingle(strRecord.Substring(143, 10))
            sngLongitude = Convert.ToSingle(strRecord.Substring(153, 11))

            'Trims extra spaces from the end of the city name
            mstrCity(i) = mstrCity(i).Trim()

            'Trims CDP designation from end of the city name
            If mstrCity(i).EndsWith(" CDP") Then
                mstrCity(i) = mstrCity(i).Substring(0, mstrCity(i).Length - 3)

            End If

            'Trims other designations from the end of the city name
            If mstrCity(i).EndsWith(" town") Then
                mstrCity(i) = mstrCity(i).Substring(0, mstrCity(i).Length - 4)

            End If

            If mstrCity(i).EndsWith(" city") Then
                mstrCity(i) = mstrCity(i).Substring(0, mstrCity(i).Length - 4)

            End If

            If mstrCity(i).EndsWith(" village") Then
                mstrCity(i) = mstrCity(i).Substring(0, mstrCity(i).Length - 7)

            End If

            If mstrCity(i).EndsWith(" municipality") Then
                mstrCity(i) = mstrCity(i).Substring(0, mstrCity(i).Length - 12)

            End If

            'Trims remaining extra space from city names
            mstrCity(i) = mstrCity(i).Trim()

            'Converts latitude from a number to a string and adds "N" for northern hemisphere
            mstrLatitude(i) = sngLatitude.ToString("N3") & " N"

            'Checks to see if longitude is eastern or western hemisphere
            'Some Alaskan cities are in the eastern hemisphere
            'Negative numbers are western hemisphere, converted to a positive number and get a "W"
            'Positive numbers are eastern hemisphere and get an "E"
            If sngLongitude < 0 Then
                mstrLongitude(i) = Math.Abs(sngLongitude).ToString("N3") & " W"
            Else
                mstrLongitude(i) = sngLongitude.ToString("N3") & " E"
            End If

            'Output
            rtbOut.AppendText(mstrState(i).PadRight(4) & mstrCity(i).PadRight(30) & _
            mintPop(i).ToString("n0").PadLeft(10).PadRight(12) & _
            mintHousingUnits(i).ToString("n0").PadLeft(10).PadRight(12) & _
            msngLandArea(i).ToString("n3").PadLeft(10).PadRight(12) & _
            msngWaterArea(i).ToString("n3").PadLeft(10).PadRight(12) & _
            mstrLatitude(i).PadLeft(12).PadRight(14) & _
            mstrLongitude(i).PadLeft(13).PadRight(15) & vbNewLine)

            lblRead.Text = i.ToString("N0")
            lblRead.Refresh()

            'Adds to record counter
            i += 1

        Loop

        srdData.Close()

    End Sub

    Private Sub btnSave_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnSave.Click
        'Builds output string and writes to data file
        Dim swrCities As System.IO.StreamWriter
        Dim i As Integer
        Dim strDetail As String

        swrCities = New System.IO.StreamWriter("Cities.dat")

        For i = 0 To mstrCity.GetUpperBound(0)
            strDetail = ""
            strDetail = mstrState(i) & "," & mstrCity(i) & "," & mintPop(i).ToString & "," & _
            mintHousingUnits(i).ToString & "," & msngLandArea(i).ToString & "," & _
            msngWaterArea(i).ToString & "," & mstrLatitude(i) & "," & _
            mstrLongitude(i)

            swrCities.WriteLine(strDetail)

            lblSaved.Text = i.ToString("N0")
            lblSaved.Refresh()

        Next i

        swrCities.Close()

    End Sub
End Class
